diff --git a/doc/src/sgml/ref/psql-ref.sgml b/doc/src/sgml/ref/psql-ref.sgml
index fc16e6c0c4..b96b5dedb6 100644
--- a/doc/src/sgml/ref/psql-ref.sgml
+++ b/doc/src/sgml/ref/psql-ref.sgml
@@ -1183,7 +1183,9 @@ testdb=&gt;
         columns of the table are shown, as is the presence of OIDs in the
         table, the view definition if the relation is a view, a non-default
         <link linkend="sql-createtable-replica-identity">replica
-        identity</link> setting.
+        identity</link> setting, the access method name
+        <link linkend="sql-create-access-method"> if the relation has access
+        method.</link>
         </para>
 
         <para>
diff --git a/src/bin/psql/describe.c b/src/bin/psql/describe.c
index d81f1575bf..ac6a93cd0b 100644
--- a/src/bin/psql/describe.c
+++ b/src/bin/psql/describe.c
@@ -3678,7 +3678,7 @@ listTables(const char *tabtypes, const char *pattern, bool verbose, bool showSys
 	PGresult   *res;
 	printQueryOpt myopt = pset.popt;
 	int			cols_so_far;
-	bool		translate_columns[] = {false, false, true, false, false, false, false, false};
+	bool		translate_columns[] = {false, false, true, false, false, false, false, false, false};
 
 	/* If tabtypes is empty, we default to \dtvmsE (but see also command.c) */
 	if (!(showTables || showIndexes || showViews || showMatViews || showSeq || showForeign))
@@ -3751,6 +3751,12 @@ listTables(const char *tabtypes, const char *pattern, bool verbose, bool showSys
 		 * to; this might change with future additions to the output columns.
 		 */
 
+		if (pset.sversion >= 120000 && !pset.hide_tableam &&
+			(showTables || showMatViews || showIndexes))
+			appendPQExpBuffer(&buf,
+							  ",\n  am.amname as \"%s\"",
+							  gettext_noop("Access Method"));
+
 		/*
 		 * As of PostgreSQL 9.0, use pg_table_size() to show a more accurate
 		 * size of a table, including FSM, VM and TOAST tables.
@@ -3772,6 +3778,12 @@ listTables(const char *tabtypes, const char *pattern, bool verbose, bool showSys
 	appendPQExpBufferStr(&buf,
 						 "\nFROM pg_catalog.pg_class c"
 						 "\n     LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace");
+
+	if (pset.sversion >= 120000 && !pset.hide_tableam &&
+		(showTables || showMatViews || showIndexes))
+		appendPQExpBufferStr(&buf,
+						 "\n     LEFT JOIN pg_catalog.pg_am am ON am.oid = c.relam");
+
 	if (showIndexes)
 		appendPQExpBufferStr(&buf,
 							 "\n     LEFT JOIN pg_catalog.pg_index i ON i.indexrelid = c.oid"
diff --git a/src/test/regress/expected/psql.out b/src/test/regress/expected/psql.out
index 555d464f91..2d0fc717a0 100644
--- a/src/test/regress/expected/psql.out
+++ b/src/test/regress/expected/psql.out
@@ -2795,20 +2795,31 @@ Argument data types | numeric
 Type                | func
 
 \pset tuples_only false
--- check conditional tableam display
--- Create a heap2 table am handler with heapam handler
+-- check conditional am display
+\pset expanded off
+CREATE SCHEMA conditional_tableam_display;
+CREATE ROLE	conditional_tableam_display_role;
+ALTER SCHEMA conditional_tableam_display OWNER TO conditional_tableam_display_role;
+SET search_path TO conditional_tableam_display;
 CREATE ACCESS METHOD heap_psql TYPE TABLE HANDLER heap_tableam_handler;
+SET role TO conditional_tableam_display_role;
 CREATE TABLE tbl_heap_psql(f1 int, f2 char(100)) using heap_psql;
 CREATE TABLE tbl_heap(f1 int, f2 char(100)) using heap;
+CREATE VIEW view_heap_psql AS SELECT f1 from tbl_heap_psql;
+CREATE MATERIALIZED VIEW mat_view_heap_psql USING heap_psql AS SELECT f1 from tbl_heap_psql;
+CREATE INDEX tbl_heap_psql_idx ON tbl_heap_psql(f1);
+CREATE SEQUENCE foo_seq START WITH 1;
 \d+ tbl_heap_psql
-                                   Table "public.tbl_heap_psql"
+                        Table "conditional_tableam_display.tbl_heap_psql"
  Column |      Type      | Collation | Nullable | Default | Storage  | Stats target | Description 
 --------+----------------+-----------+----------+---------+----------+--------------+-------------
  f1     | integer        |           |          |         | plain    |              | 
  f2     | character(100) |           |          |         | extended |              | 
+Indexes:
+    "tbl_heap_psql_idx" btree (f1)
 
 \d+ tbl_heap
-                                     Table "public.tbl_heap"
+                           Table "conditional_tableam_display.tbl_heap"
  Column |      Type      | Collation | Nullable | Default | Storage  | Stats target | Description 
 --------+----------------+-----------+----------+---------+----------+--------------+-------------
  f1     | integer        |           |          |         | plain    |              | 
@@ -2816,24 +2827,92 @@ CREATE TABLE tbl_heap(f1 int, f2 char(100)) using heap;
 
 \set HIDE_TABLEAM off
 \d+ tbl_heap_psql
-                                   Table "public.tbl_heap_psql"
+                        Table "conditional_tableam_display.tbl_heap_psql"
  Column |      Type      | Collation | Nullable | Default | Storage  | Stats target | Description 
 --------+----------------+-----------+----------+---------+----------+--------------+-------------
  f1     | integer        |           |          |         | plain    |              | 
  f2     | character(100) |           |          |         | extended |              | 
+Indexes:
+    "tbl_heap_psql_idx" btree (f1)
 Access method: heap_psql
 
 \d+ tbl_heap
-                                     Table "public.tbl_heap"
+                           Table "conditional_tableam_display.tbl_heap"
  Column |      Type      | Collation | Nullable | Default | Storage  | Stats target | Description 
 --------+----------------+-----------+----------+---------+----------+--------------+-------------
  f1     | integer        |           |          |         | plain    |              | 
  f2     | character(100) |           |          |         | extended |              | 
 Access method: heap
 
+\d+
+                                                                        List of relations
+           Schema            |        Name        |       Type        |              Owner               | Persistence | Access Method |    Size    | Description 
+-----------------------------+--------------------+-------------------+----------------------------------+-------------+---------------+------------+-------------
+ conditional_tableam_display | foo_seq            | sequence          | conditional_tableam_display_role | permanent   |               | 8192 bytes | 
+ conditional_tableam_display | mat_view_heap_psql | materialized view | conditional_tableam_display_role | permanent   | heap_psql     | 0 bytes    | 
+ conditional_tableam_display | tbl_heap           | table             | conditional_tableam_display_role | permanent   | heap          | 0 bytes    | 
+ conditional_tableam_display | tbl_heap_psql      | table             | conditional_tableam_display_role | permanent   | heap_psql     | 0 bytes    | 
+ conditional_tableam_display | view_heap_psql     | view              | conditional_tableam_display_role | permanent   |               | 0 bytes    | 
+(5 rows)
+
+\di+
+                                                                          List of relations
+           Schema            |       Name        | Type  |              Owner               |     Table     | Persistence | Access Method |    Size    | Description 
+-----------------------------+-------------------+-------+----------------------------------+---------------+-------------+---------------+------------+-------------
+ conditional_tableam_display | tbl_heap_psql_idx | index | conditional_tableam_display_role | tbl_heap_psql | permanent   | btree         | 8192 bytes | 
+(1 row)
+
+\dm+
+                                                                       List of relations
+           Schema            |        Name        |       Type        |              Owner               | Persistence | Access Method |  Size   | Description 
+-----------------------------+--------------------+-------------------+----------------------------------+-------------+---------------+---------+-------------
+ conditional_tableam_display | mat_view_heap_psql | materialized view | conditional_tableam_display_role | permanent   | heap_psql     | 0 bytes | 
+(1 row)
+
+-- following do not have am hence the column is not displayed
+\ds+
+                                                      List of relations
+           Schema            |  Name   |   Type   |              Owner               | Persistence |    Size    | Description 
+-----------------------------+---------+----------+----------------------------------+-------------+------------+-------------
+ conditional_tableam_display | foo_seq | sequence | conditional_tableam_display_role | permanent   | 8192 bytes | 
+(1 row)
+
+\dv+
+                                                      List of relations
+           Schema            |      Name      | Type |              Owner               | Persistence |  Size   | Description 
+-----------------------------+----------------+------+----------------------------------+-------------+---------+-------------
+ conditional_tableam_display | view_heap_psql | view | conditional_tableam_display_role | permanent   | 0 bytes | 
+(1 row)
+
+\dE+
+                        List of relations
+ Schema | Name | Type | Owner | Persistence | Size | Description 
+--------+------+------+-------+-------------+------+-------------
+(0 rows)
+
 \set HIDE_TABLEAM on
-DROP TABLE tbl_heap, tbl_heap_psql;
+\d+
+                                                                List of relations
+           Schema            |        Name        |       Type        |              Owner               | Persistence |    Size    | Description 
+-----------------------------+--------------------+-------------------+----------------------------------+-------------+------------+-------------
+ conditional_tableam_display | foo_seq            | sequence          | conditional_tableam_display_role | permanent   | 8192 bytes | 
+ conditional_tableam_display | mat_view_heap_psql | materialized view | conditional_tableam_display_role | permanent   | 0 bytes    | 
+ conditional_tableam_display | tbl_heap           | table             | conditional_tableam_display_role | permanent   | 0 bytes    | 
+ conditional_tableam_display | tbl_heap_psql      | table             | conditional_tableam_display_role | permanent   | 0 bytes    | 
+ conditional_tableam_display | view_heap_psql     | view              | conditional_tableam_display_role | permanent   | 0 bytes    | 
+(5 rows)
+
+RESET role;
+RESET search_path;
+DROP SCHEMA conditional_tableam_display CASCADE;
+NOTICE:  drop cascades to 5 other objects
+DETAIL:  drop cascades to table conditional_tableam_display.tbl_heap_psql
+drop cascades to table conditional_tableam_display.tbl_heap
+drop cascades to view conditional_tableam_display.view_heap_psql
+drop cascades to materialized view conditional_tableam_display.mat_view_heap_psql
+drop cascades to sequence conditional_tableam_display.foo_seq
 DROP ACCESS METHOD heap_psql;
+DROP ROLE conditional_tableam_display_role;
 -- test numericlocale (as best we can without control of psql's locale)
 \pset format aligned
 \pset expanded off
diff --git a/src/test/regress/sql/psql.sql b/src/test/regress/sql/psql.sql
index 5a16080980..a21478ba09 100644
--- a/src/test/regress/sql/psql.sql
+++ b/src/test/regress/sql/psql.sql
@@ -455,20 +455,40 @@ select 1 where false;
 \df exp
 \pset tuples_only false
 
--- check conditional tableam display
+-- check conditional am display
+\pset expanded off
 
--- Create a heap2 table am handler with heapam handler
+CREATE SCHEMA conditional_tableam_display;
+CREATE ROLE	conditional_tableam_display_role;
+ALTER SCHEMA conditional_tableam_display OWNER TO conditional_tableam_display_role;
+SET search_path TO conditional_tableam_display;
 CREATE ACCESS METHOD heap_psql TYPE TABLE HANDLER heap_tableam_handler;
+SET role TO conditional_tableam_display_role;
 CREATE TABLE tbl_heap_psql(f1 int, f2 char(100)) using heap_psql;
 CREATE TABLE tbl_heap(f1 int, f2 char(100)) using heap;
+CREATE VIEW view_heap_psql AS SELECT f1 from tbl_heap_psql;
+CREATE MATERIALIZED VIEW mat_view_heap_psql USING heap_psql AS SELECT f1 from tbl_heap_psql;
+CREATE INDEX tbl_heap_psql_idx ON tbl_heap_psql(f1);
+CREATE SEQUENCE foo_seq START WITH 1;
 \d+ tbl_heap_psql
 \d+ tbl_heap
 \set HIDE_TABLEAM off
 \d+ tbl_heap_psql
 \d+ tbl_heap
+\d+
+\di+
+\dm+
+-- following do not have am hence the column is not displayed
+\ds+
+\dv+
+\dE+
 \set HIDE_TABLEAM on
-DROP TABLE tbl_heap, tbl_heap_psql;
+\d+
+RESET role;
+RESET search_path;
+DROP SCHEMA conditional_tableam_display CASCADE;
 DROP ACCESS METHOD heap_psql;
+DROP ROLE conditional_tableam_display_role;
 
 -- test numericlocale (as best we can without control of psql's locale)
 
